[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-devel
Subject:    From qDebug() to kdDebug()
From:       Gioele Barabucci <dev () gioelebarabucci ! com>
Date:       2001-05-30 16:49:37
[Download RAW message or body]

Bored from noisy qDebug() calls I have made moved to kdDebug() some files 
from kdelibs and kdebase.
They compile fine with current cvs.



PS.: kdelibs and kdebase take ages to make a cvs diff from a 56k box
["kdebug_base.diff" (text/plain)]

? kdebug.diff
? doc/kate/Makefile.in
? kcontrol/usbview/Makefile.in
Index: kaddressbook/contactentry.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/contactentry.cpp,v
retrieving revision 1.6
diff -u -3 -p -r1.6 contactentry.cpp
--- kaddressbook/contactentry.cpp	2001/04/16 23:15:33	1.6
+++ kaddressbook/contactentry.cpp	2001/05/30 16:31:43
@@ -183,9 +183,9 @@ void ContactEntry::load( QDataStream &in
     for (uint i=0;i < numItems;i++)
 	{
 	in >> key;
-	//qDebug(" ContactEntry::load key = %s", key.latin1());
+	//kdDebug() << " ContactEntry::load key = " << key.latin1() << endl;
 	in >> item;
-	//qDebug(" ContactEntry::load item = %s", item.latin1());
+	//kdDebug() << " ContactEntry::load item = " << item.latin1() << endl;
 	dict.replace(key, new QString(item));
 	}
     }
@@ -214,9 +214,9 @@ void ContactEntry::insert( const QString
   dict.insert( key, item );
   if (!internal && !fLoading)
       {
-      //qDebug("ContactEntry::insert %s=%s int=%d", key.latin1(), item->latin1(),
-      //     (int) internal); 
-      _setModified();
+      //kdDebug() << "ContactEntry::insert " << key.latin1() << "=" <<
+      //  item->latin1() << " int=" << (int) internal << endl; 
+         _setModified();
       }
   emit changed();
 }
@@ -243,9 +243,9 @@ void ContactEntry::_replace(const QStrin
 	  dict.replace( key, item );
       if (!internal && !fLoading)
 	  {
-	  //qDebug("ContactEntry::replace %s=%s int=%d", key.latin1(),
-	  // item->latin1(), (int) internal);  
-	  _setModified();
+      //kdDebug() << "ContactEntry::replace " << key.latin1() << "=" <<
+      //  item->latin1() << " int=" << (int) internal << endl; 
+	   _setModified();
 	  }
       emit changed();
       }
@@ -255,15 +255,16 @@ void ContactEntry::_replace(const QStrin
     dict.replace( key, item );
     if (!internal && !fLoading)
 	{
-	_setModified();
-	//qDebug("ContactEntry::replace %s=%s int=%d", key.latin1(),
-	//      item->latin1(), (int) internal);
+	_setModified();   
+      //kdDebug() << "ContactEntry::replace " << key.latin1() << "=" <<
+      //  item->latin1() << " int=" << (int) internal << endl; 
 	}
     emit changed();
     }
   }
   //else
-  //qDebug("ContactEntry::replace( const QString, const QString* ) passed null item");
+  //kdDebug() << "ContactEntry::replace( const QString, const QString* ) " <<
+  //  "passed null item" << endl;
   /*
   if (item && (*item == ""))
     dict.remove( key );
@@ -354,8 +355,8 @@ void ContactEntry::debug()
     {
     for (QDictIterator<QString> iter(dict);iter.current();++iter)
 	{
-	qDebug("\t'%s' : '%s'", iter.currentKey().latin1(),
-	       iter.current()->latin1());
+	  kdDebug() << "    '" << iter.currentKey().latin1() << "' : '" <<
+            iter.current()->latin1() << endl;
 	}
     }
 
@@ -366,7 +367,7 @@ void ContactEntry::setModified(bool v)
 	val = 1;
     QString * valStr = new QString(QString::number(val));
     _replace("X-CUSTOM-KPILOT-MODIFIED", valStr, true);
-    // qDebug("\tContactEntry::setModified %d", val);
+    // kdDebug() << "    ContactEntry::setModified " << val << endl;
     }
 
 bool ContactEntry::isModified() const
@@ -407,7 +408,7 @@ QDataStream &operator>>(QDataStream &in,
 
 QDataStream &operator<<(QDataStream &out, const QDict<ContactEntry> &entries)
     {
-    //qDebug("  Writing out QDict<ContactEntry>");
+    //kdDebug() << "  Writing out QDict<ContactEntry>" << endl;
     out << entries.count();
     for (QDictIterator<ContactEntry> iter(entries);iter.current();++iter)
 	{
@@ -418,16 +419,16 @@ QDataStream &operator<<(QDataStream &out
     }
 QDataStream &operator>>(QDataStream &in, QDict<ContactEntry> &entries)
     {
-    //qDebug("  Reading in QDict<ContactEntry>");
+    //kdDebug() << "  Reading in QDict<ContactEntry>" << endl;
     entries.setAutoDelete(true);
     uint numEntries = 0;
     in >> numEntries;
-    //qDebug("  reading %d entries", numEntries);
+    //kdDebug() << "  reading " << numEntries << " entries" << endl;
     QString key;
     for (uint i=0;i < numEntries;++i)
 	{
 	in >> key;
-	//qDebug(" read key = %s", key.latin1());
+	//kdDebug() << " read key = " << key.latin1() << endl;
 	ContactEntry *entry = new ContactEntry();
 	entry->load(in);
 	entries.insert(key, entry);
Index: kaddressbook/contactentry.h
===================================================================
RCS file: /cvs/kdebase/kaddressbook/contactentry.h,v
retrieving revision 1.5
diff -u -3 -p -r1.5 contactentry.h
--- kaddressbook/contactentry.h	2001/04/16 23:15:33	1.5
+++ kaddressbook/contactentry.h	2001/05/30 16:31:43
@@ -148,7 +148,7 @@ public:
 
   /**
    * For debugging purposes only, print out the values stored in the
-   * this class using qDebug
+   * this class using kdDebug()
    */
   void debug();
 
Index: kaddressbook/contactentrylist.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/contactentrylist.cpp,v
retrieving revision 1.2
diff -u -3 -p -r1.2 contactentrylist.cpp
--- kaddressbook/contactentrylist.cpp	2001/04/13 22:19:44	1.2
+++ kaddressbook/contactentrylist.cpp	2001/05/30 16:31:43
@@ -43,7 +43,7 @@ void ContactEntryList::refresh()
     addrBook = 0;
   } 
   else {
-    qDebug("KMKernel::init: KabApi initialized.");
+    kdDebug() << "KMKernel::init: KabApi initialized." << endl;
   }
 
   int num = addrBook->addressbook()->noOfEntries();
@@ -69,7 +69,7 @@ void ContactEntryList::commit()
     addrBook->addressbook()->remove( key ); // check rc
   }
   if (addrBook->addressbook()->save("", true)!=AddressBook::NoError)
-    qDebug( "Error occurred trying to update database" );
+    kdDebug() << "Error occurred trying to update database" << endl;
   addrBook->addressbook()->close();
 }
 
@@ -79,11 +79,11 @@ QString ContactEntryList::insert( Contac
   AddressBook::Entry empty;
   AddressBook::Entry entry = ContactEntryToKabEntry( item, empty );  
   if (AddressBook::NoError != addrBook->addressbook()->add( entry, key, true )) {
-    qDebug( "Error occurred trying to insert entry" );
+    kdDebug() << "Error occurred trying to insert entry" << endl;
     // TODO show a message box here
   }
   if (addrBook->addressbook()->save("", true)!=AddressBook::NoError)
-    qDebug( "Error occurred trying to update database" );
+    kdDebug() << "Error occurred trying to update database" << endl;
 
   ceDict.insert( key.getKey(), item );
   return key.getKey();
@@ -113,7 +113,7 @@ void ContactEntryList::replace( const QS
   KabKey kabKey;
   kabKey.setKey( key.local8Bit() );
   if (AddressBook::NoError != addrBook->addressbook()->getEntry( kabKey, old )) {
-    qDebug( "Error occurred trying to update entry" );
+    kdDebug() << "Error occurred trying to update entry" << endl;
     // TODO show a message box here
     return;
   }
@@ -123,7 +123,7 @@ void ContactEntryList::replace( const QS
   ceDict.replace( key, item );
 
   if (addrBook->addressbook()->save("", true)!=AddressBook::NoError)
-    qDebug( "Error occurred trying to update database" );
+    kdDebug() << "Error occurred trying to update database" << endl;
 }
 
 ContactEntry* ContactEntryList::KabEntryToContactEntry( AddressBook::Entry entry )
Index: kaddressbook/contactlistview.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/contactlistview.cpp,v
retrieving revision 1.1
diff -u -3 -p -r1.1 contactlistview.cpp
--- kaddressbook/contactlistview.cpp	2001/05/28 22:32:07	1.1
+++ kaddressbook/contactlistview.cpp	2001/05/30 16:31:43
@@ -130,7 +130,8 @@ ContactEntry *ContactListViewItem::getEn
   ContactEntryList *cel = parent()->getKAddressBookView()->contactEntryList();
   ContactEntry *ce = cel->find( entryKey_ );
   if (!ce)  // can only happen to shared address book
-    qDebug( "ContactListViewItem::getEntry() Associated ContactEntry not found" );
+    kdDebug() << "ContactListViewItem::getEntry() " <<
+      "Associated ContactEntry not found" << endl;
   return ce;
 }
 
Index: kaddressbook/entryeditorwidget.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/entryeditorwidget.cpp,v
retrieving revision 1.19
diff -u -3 -p -r1.19 entryeditorwidget.cpp
--- kaddressbook/entryeditorwidget.cpp	2001/05/26 05:45:59	1.19
+++ kaddressbook/entryeditorwidget.cpp	2001/05/30 16:31:46
@@ -478,7 +478,7 @@ void ContactDialog::monitorCompany()
 
 void ContactDialog::updateFileAs()
 {
-  qDebug( "updateFileAs" );
+  kdDebug() << "updateFileAs" << endl;
   cbFileAs->clear();
   QString surnameFirst;
   if (ce->find( "N" )) {
@@ -514,14 +514,15 @@ void ContactDialog::updateFileAs()
 // has been used to enter the name
 void ContactDialog::parseName()
 {
-  qDebug( "parseName()" );
+  kdDebug() << "parseName()" << endl;
   if (!ce->find( ".AUXCONTACT-N" ))
     return;
-  //  qDebug( ".AUX" + *ce->find( ".AUXCONTACT-N" ) + " curname " + curName);
+  //  kdDebug() << ".AUX" << *ce->find( ".AUXCONTACT-N" ) <<
+  //    " curname " << curName << endl;
   if (*ce->find( ".AUXCONTACT-N" ) == curName)
     return;
   curName = (*ce->find( ".AUXCONTACT-N" )).simplifyWhiteSpace();
-  //  qDebug( "curName " + curName );
+  //  kdDebug() << "curName " << curName << endl;
   ce->replace( ".AUXCONTACT-N", new QString( curName ));
   QString name = curName;
   QString prefix;
Index: kaddressbook/kaddressbookview.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/kaddressbookview.cpp,v
retrieving revision 1.1
diff -u -3 -p -r1.1 kaddressbookview.cpp
--- kaddressbook/kaddressbookview.cpp	2001/05/28 22:32:07	1.1
+++ kaddressbook/kaddressbookview.cpp	2001/05/30 16:31:47
@@ -178,7 +178,7 @@ KAddressBookView::KAddressBookView( Cont
 
 KAddressBookView::~KAddressBookView()
 {
-  qDebug( "Destroying KAddressBookView" );
+  kdDebug() << "Destroying KAddressBookView" << endl;
 }
 
 void KAddressBookView::setupListView()
@@ -370,7 +370,8 @@ void KAddressBookView::itemSelected( QLi
     QString entryKey = plvi->entryKey();
     ContactEntry *ce = cel->find( entryKey );
     if (!ce) { // Another process deleted it(!)
-      qDebug( "KAddressBookView::itemSelected Associated entry not found" );
+      kdDebug() <<
+        "KAddressBookView::itemSelected Associated entry not found" << endl;
       return;
     }
     PabContactDialog *cd = new PabContactDialog( title, this, 0, entryKey, ce );
@@ -436,7 +437,7 @@ void KAddressBookView::paste()
 
 void KAddressBookView::clear()
 {
-  qDebug( "clear" );
+  kdDebug() << "clear" << endl;
   QListViewItem *item = mListView->currentItem();
   ContactListViewItem *lvi = dynamic_cast< ContactListViewItem* >(item);
   if (lvi) {
Index: kaddressbook/undocmds.cpp
===================================================================
RCS file: /cvs/kdebase/kaddressbook/undocmds.cpp,v
retrieving revision 1.1
diff -u -3 -p -r1.1 undocmds.cpp
--- kaddressbook/undocmds.cpp	2001/05/28 22:32:07	1.1
+++ kaddressbook/undocmds.cpp	2001/05/30 16:31:47
@@ -5,6 +5,7 @@
 #include <qclipboard.h>
 
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "kaddressbookview.h"
 #include "contactentry.h"
@@ -126,8 +127,9 @@ void PwNewCommand::undo()
   ContactEntryList *cel = pw->contactEntryList();
   ContactEntry *tempce = cel->find( entryKey );
   if (!tempce) { // Another process deleted it already(!)
-    qDebug( "PwNewCommand::undo() Associated ContactEntry not found." );
-    qDebug( "Unable to undo insert" );
+    kdDebug() << "PwNewCommand::undo() Associated ContactEntry not found." <<
+      endl;
+    kdDebug() << "Unable to undo insert" << endl;
   }
   else
     ce = new ContactEntry( *tempce );
@@ -135,7 +137,7 @@ void PwNewCommand::undo()
   if (plvi)
     delete plvi;
   else // Should never happen
-    qDebug( "PwNewCommand::undo() missing listViewItem." );
+    kdDebug() << "PwNewCommand::undo() missing listViewItem." << endl;
   cel->remove( entryKey );
 }
 

["kdebug_libs.diff" (text/x-c++)]

? kdebug.diff
Index: khtml/css/cssstyleselector.cpp
===================================================================
RCS file: /cvs/kdelibs/khtml/css/cssstyleselector.cpp,v
retrieving revision 1.147
diff -u -3 -p -r1.147 cssstyleselector.cpp
--- khtml/css/cssstyleselector.cpp	2001/05/30 09:35:40	1.147
+++ khtml/css/cssstyleselector.cpp	2001/05/30 16:32:11
@@ -95,8 +95,8 @@ CSSStyleSelector::CSSStyleSelector(Docum
 
     buildLists();
 
-    kdDebug() << "number of style sheets in document " << authorStyleSheets.count() \
                << endl;
-     kdDebug() << "CSSStyleSelector: author style has " << authorStyle->count() << " \
elements"<< endl; +    kdDebug( 6080 ) << "number of style sheets in document " << \
authorStyleSheets.count() << endl; +     kdDebug( 6080 ) << "CSSStyleSelector: author \
style has " << authorStyle->count() << " elements"<< endl;  //     if ( userStyle )
 //     kdDebug() << "CSSStyleSelector: user style has " << userStyle->count() << " \
elements"<< endl;  
@@ -659,7 +659,7 @@ void CSSStyleSelector::buildLists()
 #if 0
     // and now the same for the selector map
     for ( unsigned int sel = 0; sel < selectors_size; ++sel ) {
-        qDebug( "trying for sel: %d", sel );
+        kdDebug( 6080 ) << "trying for sel: " << sel << endl;
         int len = 0;
         int offset = 0;
         bool matches = false;
@@ -672,7 +672,7 @@ void CSSStyleSelector::buildLists()
 
             if ( matches != ( selectorCache[i].state == Unknown ) ) {
                 if ( matches ) {
-                    qDebug( "new: offs: %d,  len: %d", offset, len );
+                    kdDebug( 6080 ) << "new: offs: " << offset << " len: " << len << \
endl;  matches = false;
                 }
                 else {
Index: khtml/html/htmltokenizer.cpp
===================================================================
RCS file: /cvs/kdelibs/khtml/html/htmltokenizer.cpp,v
retrieving revision 1.170
diff -u -3 -p -r1.170 htmltokenizer.cpp
--- khtml/html/htmltokenizer.cpp	2001/05/28 20:34:33	1.170
+++ khtml/html/htmltokenizer.cpp	2001/05/30 16:32:14
@@ -713,8 +713,9 @@ void HTMLTokenizer::parseTag(DOMStringIt
         int l = 0;
         while(l < src.length() && (*(src.current()+l)).latin1() != '>')
             l++;
-        qDebug("src is now: *%s*, tquote: %d",
-               QConstString((QChar*)src.current(), l).string().latin1(), tquote);
+        kdDebug( 6036 ) << "src is now: *" <<
+            QConstString((QChar*)src.current(), l).string().latin1() <<
+            "*, tquote: " << tquote << endl;
 #endif
         switch(tag) {
         case NoTag:
@@ -724,7 +725,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case TagName:
         {
 #if defined(TOKEN_DEBUG) &&  TOKEN_DEBUG > 1
-            qDebug("TagName");
+            kdDebug( 6036 ) << "TagName" << endl;
 #endif
             if (searchCount > 0)
             {
@@ -815,7 +816,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case SearchAttribute:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-                qDebug("SearchAttribute");
+                kdDebug( 6036 ) << "SearchAttribute" << endl;
 #endif
             bool atespace = false;
             ushort curchar;
@@ -844,7 +845,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case AttributeName:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-                qDebug("AttributeName");
+                kdDebug( 6036 ) << "AttributeName" << endl;
 #endif
             ushort curchar;
             int ll = kMin(src.length(), CBUFLEN-cBufferPos);
@@ -886,7 +887,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case SearchEqual:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-                qDebug("SearchEqual");
+                kdDebug( 6036 ) << "SearchEqual" << endl;
 #endif
             ushort curchar;
             while(src.length()) {
@@ -940,7 +941,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case QuotedValue:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-                qDebug("QuotedValue");
+                kdDebug( 6036 ) << "QuotedValue" << endl;
 #endif
             while(src.length()) {
                 checkBuffer();
@@ -994,7 +995,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case Value:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-            qDebug("Value");
+            kdDebug( 6036 ) << "Value" << endl;
 #endif
             ushort curchar;
             while(src.length()) {
@@ -1034,7 +1035,7 @@ void HTMLTokenizer::parseTag(DOMStringIt
         case SearchEnd:
         {
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 1
-                qDebug("SearchEnd");
+                kdDebug( 6036 ) << "SearchEnd" << endl;
 #endif
             while(src.length()) {
                 curchar = src->unicode();
Index: khtml/misc/loader.cpp
===================================================================
RCS file: /cvs/kdelibs/khtml/misc/loader.cpp,v
retrieving revision 1.82
diff -u -3 -p -r1.82 loader.cpp
--- khtml/misc/loader.cpp	2001/05/14 12:44:06	1.82
+++ khtml/misc/loader.cpp	2001/05/30 16:32:16
@@ -556,8 +556,10 @@ void CachedImage::do_notify(const QPixma
 void CachedImage::movieUpdated( const QRect& r )
 {
 #ifdef CACHE_DEBUG
-    qDebug("movie updated %d/%d/%d/%d, pixmap size %d/%d", r.x(), r.y(), r.right(), \
                r.bottom(),
-           m->framePixmap().size().width(), m->framePixmap().size().height());
+    kdDebug( 6060 ) << "movie updated " << 
+        r.x() << "/" << r.y() << "/" << r.right() << "/" << r.bottom() << 
+        ", pixmap size " << m->framePixmap().size().width() << 
+        "/" << m->framePixmap().size().height() << endl;
 #endif
 
     do_notify(m->framePixmap(), r);
@@ -566,7 +568,7 @@ void CachedImage::movieUpdated( const QR
 void CachedImage::movieStatus(int status)
 {
 #ifdef CACHE_DEBUG
-    qDebug("movieStatus(%d)", status);
+    kdDebug( 6060 ) << "movieStatus(" << status << ")" << endl;
 #endif
     if((status == QMovie::EndOfFrame) || (status == QMovie::EndOfMovie))
     {
Index: khtml/misc/loader_jpeg.cpp
===================================================================
RCS file: /cvs/kdelibs/khtml/misc/loader_jpeg.cpp,v
retrieving revision 1.9
diff -u -3 -p -r1.9 loader_jpeg.cpp
--- khtml/misc/loader_jpeg.cpp	2001/04/17 08:56:22	1.9
+++ khtml/misc/loader_jpeg.cpp	2001/05/30 16:32:18
@@ -19,7 +19,6 @@
     AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
     AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
     CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
 */
 
 #ifdef HAVE_CONFIG_H
@@ -31,8 +30,11 @@
 
 #include <stdio.h>
 #include <setjmp.h>
+
 #include <qdatetime.h>
 
+#include <kdebug.h>
+
 extern "C" {
 #define XMD_H
 #include <jpeglib.h>
@@ -94,7 +96,7 @@ extern "C" {
     boolean khtml_fill_input_buffer(j_decompress_ptr cinfo)
     {
 #ifdef BUFFER_DEBUG
-        qDebug("khtml_fill_input_buffer called!");
+        kdDebug() << "khtml_fill_input_buffer called!" << endl;
 #endif
 
         khtml_jpeg_source_mgr* src = (khtml_jpeg_source_mgr*)cinfo->src;
@@ -106,7 +108,7 @@ extern "C" {
             src->buffer[1] = (JOCTET) JPEG_EOI;
             src->bytes_in_buffer = 2;
 #ifdef BUFFER_DEBUG
-            qDebug("...returning TRUE!");
+            kdDebug() << "...returning TRUE!" << endl;
 #endif
             return TRUE;
         }
@@ -121,7 +123,7 @@ extern "C" {
             return; /* required noop */
 
 #ifdef BUFFER_DEBUG
-        qDebug("khtml_skip_input_data (%d) called!", num_bytes);
+        kdDebug() << "khtml_skip_input_data (" << num_bytes << ") called!" << endl;
 #endif
 
         khtml_jpeg_source_mgr* src = (khtml_jpeg_source_mgr*)cinfo->src;
@@ -130,10 +132,10 @@ extern "C" {
         unsigned int skipbytes = QMIN(src->bytes_in_buffer, src->skip_input_bytes);
 
 #ifdef BUFFER_DEBUG
-        qDebug("skip_input_bytes is now %d", src->skip_input_bytes);
-        qDebug("skipbytes is now %d", skipbytes);
-        qDebug("valid_buffer_len is before %d", src->valid_buffer_len);
-        qDebug("bytes_in_buffer is %d", src->bytes_in_buffer);
+        kdDebug() << "skip_input_bytes is now " << src->skip_input_bytes << endl;
+        kdDebug() << "skipbytes is now " << skipbytes << endl;
+        kdDebug() << "valid_buffer_len is before " << src->valid_buffer_len << endl;
+        kdDebug() << "bytes_in_buffer is " << src->bytes_in_buffer << endl;
 #endif
 
         if(skipbytes < src->bytes_in_buffer)
@@ -147,8 +149,8 @@ extern "C" {
         cinfo->src->next_input_byte = (JOCTET *) src->buffer;
         cinfo->src->bytes_in_buffer = (size_t) src->valid_buffer_len;
 #ifdef BUFFER_DEBUG
-        qDebug("valid_buffer_len is afterwards %d", src->valid_buffer_len);
-        qDebug("skip_input_bytes is now %d", src->skip_input_bytes);
+        kdDebug() << "valid_buffer_len is afterwards " << src->valid_buffer_len << \
endl; +        kdDebug() << "skip_input_bytes is now " << src->skip_input_bytes << \
endl;  #endif
     }
 }
Index: khtml/rendering/render_hr.cpp
===================================================================
RCS file: /cvs/kdelibs/khtml/rendering/render_hr.cpp,v
retrieving revision 1.16
diff -u -3 -p -r1.16 render_hr.cpp
--- khtml/rendering/render_hr.cpp	2001/05/11 23:13:18	1.16
+++ khtml/rendering/render_hr.cpp	2001/05/30 16:32:18
@@ -83,12 +83,12 @@ void RenderHR::print(QPainter *p, int _x
     case JUSTIFY:
     case CENTER:
     case KONQ_CENTER:
-        //kdDebug() << "centered" << endl;
+        //kdDebug(6040) << "centered" << endl;
         xp += (m_width - m_length)/2;
         break;
     }
 
-    kdDebug() << "tx = " << xp << " ty=" << _ty << " m_width = " << m_width << " \
length = " << m_length << " m_height: " << m_height <<  endl; +    kdDebug(6040) << \
"tx = " << xp << " ty=" << _ty << " m_width = " << m_width << " length = " << \
m_length << " m_height: " << m_height <<  endl;  
     printBorder(p, xp, _ty, m_length, m_height, style());
 
@@ -111,13 +111,14 @@ void RenderHR::layout()
 {
     if ( layouted() ) return;
 
-    qDebug( "RenderHR::layout!" );
+    kdDebug(6040) << "RenderHR::layout!" << endl;
 
     calcWidth();
     calcHeight();
 
-    qDebug( "minWidth: %d, maxWidth: %d, width: %d,  height: %d",
-            m_minWidth, m_maxWidth, m_width, m_height );
+    kdDebug(6040) << "minWidth: " << m_minWidth <<
+        " maxWidth: " << m_maxWidth << " width: " << m_width << 
+        " height: " << m_height << endl;
 
     //  setLayouted();
 }
Index: kio/kdirwatch.cpp
===================================================================
RCS file: /cvs/kdelibs/kio/kdirwatch.cpp,v
retrieving revision 1.48
diff -u -3 -p -r1.48 kdirwatch.cpp
--- kio/kdirwatch.cpp	2001/05/15 22:45:38	1.48
+++ kio/kdirwatch.cpp	2001/05/30 16:32:19
@@ -181,7 +181,7 @@ static void dnotify_handler(int, siginfo
   KDirWatchPrivate::Entry* e = fd_Entry->find(si->si_fd);
 
   if(!e || e->dn_fd != si->si_fd) {
-    qDebug("fatal error in KDirWatch");
+    kdDebug(7001) << "fatal error in KDirWatch" << endl;
   } else if(e->m_ctime != NO_NOTIFY)
     e->dn_dirty = true;
 }
Index: kio/klauncher/klauncher.cpp
===================================================================
RCS file: /cvs/kdelibs/kio/klauncher/klauncher.cpp,v
retrieving revision 1.50
diff -u -3 -p -r1.50 klauncher.cpp
--- kio/klauncher/klauncher.cpp	2001/05/24 20:52:34	1.50
+++ kio/klauncher/klauncher.cpp	2001/05/30 16:32:23
@@ -140,7 +140,7 @@ KLauncher::KLauncher(int _kdeinitSocket)
    if (domainname.status() != 0)
    {
       // Sever error!
-      qDebug("KLauncher: Fatal error, can't create tempfile!");
+      kdDebug(7016) << "KLauncher: Fatal error, can't create tempfile!" << endl;
       ::exit(1);
    }
    mPoolSocketName = domainname.name();
Index: kstyles/klegacy/klegacystyle.cpp
===================================================================
RCS file: /cvs/kdelibs/kstyles/klegacy/klegacystyle.cpp,v
retrieving revision 1.8
diff -u -3 -p -r1.8 klegacystyle.cpp
--- kstyles/klegacy/klegacystyle.cpp	2000/10/20 20:02:43	1.8
+++ kstyles/klegacy/klegacystyle.cpp	2001/05/30 16:32:28
@@ -26,6 +26,7 @@
 #include "klegacystyle.moc"
 #include <klocale.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 #define INCLUDE_MENUITEM_DEF
 #include <qapplication.h>
@@ -869,8 +870,8 @@ GtkObject *GtkObject::find(QRegExp &r) c
 	// this would be nice if moc could parse this file :/
 	//
 	// if (o->className() != "GtkObject") {
 	//     qDebug("object is not a GtkObject (className = '%s')",
 	// 	      o->className());
 	//     continue;
 	// }
 
@@ -1969,7 +1970,7 @@ void KLegacyStyle::polish(QWidget *widge
     }
 
     if (widget->inherits("QPopupMenu")) {
-	qDebug("polishing popup '%s'", widget->className());
+	kdDebug() << "polishing popup '" << widget->className() << "'" << endl;
 	metaobject = QPopupMenu::staticMetaObject();
 	widget->setBackgroundMode(QWidget::PaletteBackground);
     }
@@ -869,8 +870,8 @@ GtkObject *GtkObject::find(QRegExp &r) c
 	//
 	// if (o->className() != "GtkObject") {
-	//     qDebug("object is not a GtkObject (className = '%s')",
-	// 	      o->className());
+	//     kdDebug() << "object is not a GtkObject (className = '" <<
+	// 	      o->className() << "'" << endl;
 	//     continue;
 	// }


>> Visit http://master.kde.org/mailman/listinfo/kde-devel#unsub to unsubscribe <<


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic